import { RequestService } from '../RequestService';
import { Contributor, LibrariesIOResult, PaginationOptions, Project, ProjectUsage, ProjectWithDependencies, Repository, SearchOptions } from '../interfaces/';
export declare class ProjectAPI {
    private readonly requestService;
    constructor(requestService: RequestService);
    /**
     * Get information about a package and it's versions.
     * @see https://libraries.io/api#project
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getProject(platform: string, projectName: string): Promise<LibrariesIOResult<Project>>;
    /**
     * Get a list of dependencies for a version of a project, pass `latest` as version to get dependency info for the latest available version
     * @see https://libraries.io/api#project-dependencies
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param projectVersion
     */
    getProjectWithDependencies(platform: string, projectName: string, projectVersion: string): Promise<LibrariesIOResult<ProjectWithDependencies>>;
    /**
     * Get packages that have at least one version that depends on a given project.
     * @see https://libraries.io/api#project-dependents
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    getDependendents(platform: string, projectName: string, options?: PaginationOptions): Promise<LibrariesIOResult<Project[]>>;
    /**
     * Get repositories that depend on a given project.
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    getDependendentRepositories(platform: string, projectName: string, options?: PaginationOptions): Promise<LibrariesIOResult<Repository[]>>;
    /**
     * Get users that have contributed to a given project.
     * @see https://libraries.io/api#project-contributors
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     * @param options Pagination options
     */
    getContributors(platform: string, projectName: string, options?: PaginationOptions): Promise<LibrariesIOResult<Contributor[]>>;
    /**
     * Get breakdown of SourceRank score for a given project.
     * @see https://libraries.io/api#project-sourcerank
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getSourceRank(platform: string, projectName: string): Promise<LibrariesIOResult<number>>;
    /**
     * Get breakdown of version usage for a given project.
     * @param platform The project platform (e.g. "npm", "cargo", ...)
     * @param projectName The project name
     */
    getUsage(platform: string, projectName: string): Promise<LibrariesIOResult<ProjectUsage>>;
    /**
     * Search for projects.
     * @see https://libraries.io/api#project-search
     * @param query The search query
     * @param options Sorting, filter and pagination options
     */
    search(query: string, options?: SearchOptions): Promise<LibrariesIOResult<Project[]>>;
}
